advanced library

Advanced orchestration, execution engines, and isolate internals for logd.

Use this library when building custom execution engines, low-level isolate pipelines, custom serialization registries, or layout engines.

For standard application logging, import package:logd/logd.dart instead.

Classes

Arena
A fallback implementation of the Arena resource pool for web/browser runtimes.
ArenaDocument
ArenaEngine
A fallback stub for ArenaEngine on unsupported platforms (like Web).
AsyncHandler
A Handler that directly processes logs synchronously on the main thread under web/browser runtimes where standard isolates are unsupported.
HandlerContext
A reusable encoding buffer for log serialization.
IsolateSink
A fallback stub for IsolateSink on unsupported platforms (like Web).
LogEngine
The orchestration layer for the logging pipeline.
LogPipelineFactory
An abstraction for log resource allocation and management.
NativeEngine
A fallback stub for NativeEngine on unsupported platforms (like Web).
NativeIsolateSink
A fallback stub for NativeIsolateSink on unsupported platforms (like Web).
StandardEngine
A LogEngine that utilizes Dart language's standard heap allocation.
StandardPipelineFactory
A LogPipelineFactory that uses standard heap allocation (no pooling).