Arena class

A fallback implementation of the Arena resource pool for web/browser runtimes.

Under environments where FFI/IO is unsupported (such as Web/JS/WASM), this class transparently falls back to using standard heap allocations (StandardDocument.pooled, etc.) rather than native memory page pools. This allows logging code targeting Arena to execute without runtime crashes on all platforms.

Implemented types
Annotations
  • @experimental

Properties

hashCode int
The hash code for this object.
no setterinherited
poolSize int
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

checkoutAlignment() AlignmentNode
Checks out an AlignmentNode from the pool, or allocates a fresh one.
override
checkoutBox() BoxNode
Checks out a BoxNode from the pool, or allocates a fresh one.
override
checkoutContext() HandlerContext
Checks out a HandlerContext from the pool, or allocates a fresh one.
override
checkoutDataList<T>() List<T>
Checks out a raw List from the pool, or allocates a fresh one.
override
checkoutDataMap<K, V>() Map<K, V>
Checks out a raw Map from the pool, or allocates a fresh one.
override
checkoutDataSet<T>() Set<T>
Checks out a raw Set from the pool, or allocates a fresh one.
override
checkoutDecorated() DecoratedNode
Checks out a DecoratedNode from the pool, or allocates a fresh one.
override
checkoutDocument() LogDocument
Checks out a LogDocument from the pool, or allocates a fresh one.
override
checkoutError() ErrorNode
Checks out an ErrorNode from the pool, or allocates a fresh one.
override
checkoutFiller() FillerNode
Checks out a FillerNode from the pool, or allocates a fresh one.
override
checkoutFooter() FooterNode
Checks out a FooterNode from the pool, or allocates a fresh one.
override
checkoutGroup() GroupNode
Checks out a GroupNode from the pool, or allocates a fresh one.
override
checkoutHeader() HeaderNode
Checks out a HeaderNode from the pool, or allocates a fresh one.
override
checkoutIndentation() IndentationNode
Checks out an IndentationNode from the pool, or allocates a fresh one.
override
checkoutList() ListNode
Checks out a ListNode from the pool, or allocates a fresh one.
override
checkoutLogEntry({required String loggerName, required String origin, required LogLevel level, required String message, required String timestamp, List<CallbackInfo>? stackFrames, Object? error, StackTrace? stackTrace, Map<String, dynamic>? context}) LogEntry
checkoutMap() MapNode
Checks out a MapNode from the pool, or allocates a fresh one.
override
checkoutMessage() MessageNode
Checks out a MessageNode from the pool, or allocates a fresh one.
override
checkoutMetadata() MetadataNode
Checks out a MetadataNode from the pool, or allocates a fresh one.
override
checkoutParagraph() ParagraphNode
Checks out a ParagraphNode from the pool, or allocates a fresh one.
override
checkoutPhysicalDocument() PhysicalDocument
Checks out a PhysicalDocument from the pool, or allocates a fresh one.
override
checkoutPhysicalLine() PhysicalLine
Checks out a PhysicalLine from the pool, or allocates a fresh one.
override
checkoutRow() RowNode
Checks out a RowNode from the pool, or allocates a fresh one.
override
checkoutSection() SectionNode
Checks out a SectionNode from the pool, or allocates a fresh one.
override
checkoutTable() TableNode
Checks out a TableNode from the pool, or allocates a fresh one.
override
checkoutTableCell() TableCellNode
Checks out a TableCellNode from the pool, or allocates a fresh one.
override
checkoutTableRow() TableRowNode
Checks out a TableRowNode from the pool, or allocates a fresh one.
override
clear() → void
disposeNative() → void
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
reclaimInFlightBuffers() → void
release(Object obj) → void
Releases obj back to the pool after resetting its state.
override
releaseLogEntry(LogEntry entry) → void
toString() String
A string representation of this object.
inherited
waitForPoolCapacity() Future<void>

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

instance Arena
final