FooterNode class final

Supplementary info (origin, stack trace).

Inheritance

Constructors

FooterNode({required List<StyledText> segments, int tags = LogTag.none})
Creates a FooterNode.

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
segments List<StyledText>
The list of styled text segments that make up this content.
getter/setter pairinherited
tags int
Semantic tags describing this node.
getter/setter pairinherited

Methods

copyWith({List<StyledText>? segments, int? tags}) FooterNode
Creates a copy of this node with optional new segments or tags.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
releaseRecursive(LogPipelineFactory factory) → void
Releases this node and any children back to factory.
inherited
reset() → void
Resets this node's fields to their defaults for pool reuse.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited