LogDecorator class sealed

Base class for log document decorators, formally classified by their effect.

Decorators allow for post-processing the LogDocument after it has been constructed. This hierarchy is sealed to ensure that all decorators fall into one of the known categories, enabling automatic handling of composition complexities.

Implementers

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

decorate(LogDocument document, LogEntry entry, LogPipelineFactory factory) → void
Decorates the document in-place based on the entry, using factory for new nodes.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
paddingWidth(LogEntry entry) int
Returns the width in terminal cells this decorator adds to each line.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited