dispose method

Future<void> dispose()

Performs cleanup, such as closing file handles or network connections.

This should be called when the sink is no longer needed.

Implementation

Future<void> dispose() async {}