StandardDocument class

The standard, object-based implementation of LogDocument.

Inheritance
Implementers

Constructors

StandardDocument({List<LogNode>? nodes, Map<String, Object?>? metadata})

Properties

hashCode int
The hash code for this object.
no setteroverride
metadata Map<String, Object?>
Arbitrary metadata associated with the document.
final
nodes List<LogNode>
The root nodes of the document tree.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

endAlignment() → void
Ends the current alignment scope.
override
endBox() → void
Ends the current box scope.
override
endCell() → void
Ends the current table cell.
override
endDecorated() → void
Ends the current decorated scope.
override
endIndent() → void
Ends the current indentation scope.
override
endRow() → void
Ends the current table row.
override
endTable() → void
Ends the current table.
override
filler({required String char, int tags = LogTag.none, LogPipelineFactory? factory}) → void
Appends a filler segment to the document.
override
metadataBlock(Map<String, Object?> data, {int tags = LogTag.none, LogPipelineFactory? factory}) → void
Appends a metadata block (Map) to the document.
override
newline() → void
Appends a newline to the document.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
releaseRecursive(LogPipelineFactory factory) → void
Recursively releases this document and all its nodes back to factory.
override
reset() → void
Resets this document to an empty state so it can be reused.
override
startAlignment(LogAlignment alignment, {LogPipelineFactory? factory}) → void
Starts an alignment scope.
override
startBox({BoxBorderStyle border = BoxBorderStyle.rounded, int tags = LogTag.none, LogPipelineFactory? factory}) → void
Starts a box scope.
override
startCell({int colspan = 1, int rowspan = 1, LogPipelineFactory? factory}) → void
Starts a table cell.
override
startDecorated({required List<StyledText> leading, int leadingWidth = 0, String? leadingHint, LogPipelineFactory? factory}) → void
Starts a decorated scope (e.g. with a leading prefix).
override
startIndent(String indent, {LogStyle? style, int tags = LogTag.none, LogPipelineFactory? factory}) → void
Starts an indentation scope.
override
startRow({LogPipelineFactory? factory}) → void
Starts a table row.
override
startTable({List<int>? columnWidths, LogPipelineFactory? factory}) → void
Starts a table.
override
styledText(StyledText text, {LogPipelineFactory? factory}) → void
Appends a styled text segment to the document.
override
text(String text, {LogStyle? style, int tags = LogTag.none, LogPipelineFactory? factory}) → void
Appends a text segment to the document.
override
toString() String
A string representation of this object.
inherited
writeNode(LogNode node) → void
Appends an existing LogNode to the document.
override

Operators

operator ==(Object other) bool
The equality operator.
override