testing library

Classes

CapturedLog
Represents a logged entry captured in tests.
CaptureSink
A LogSink that captures all logged entries in memory for verification in unit tests.
TestLogger
A convenience wrapper that creates an isolated logger with a CaptureSink for unit testing.

Functions

hasLog({LogLevel? level, Object? message, String? loggerName, Map<String, dynamic>? context}) → Matcher
A custom matcher to verify logs captured in tests.