ArenaEngine class
A fallback stub for ArenaEngine on unsupported platforms (like Web).
Attempting to use this engine on non-native platforms will result in an UnsupportedError pointing the user to cross-platform alternatives.
- Implemented types
Constructors
- ArenaEngine()
-
Creates an ArenaEngine stub.
const
Properties
- factory → LogPipelineFactory
-
The factory/allocator used by this engine for pipeline resources.
no setteroverride
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
execute(
LogEntry entry, LogFormatter formatter, List< LogDecorator> decorators, LogSink sink) → Future<void> -
Executes the pipeline for a single LogEntry.
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited