IsolateSink class base
A fallback stub for IsolateSink on unsupported platforms (like Web).
Offloads log encoding/output processes to a background worker isolate. Attempting to use this sink under Web results in an UnsupportedError pointing the user to standard synchronous sinks.
Constructors
- IsolateSink(LogSink target)
- Creates an IsolateSink stub.
Properties
- enabled → bool
-
Whether this sink is currently active.
finalinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- target → LogSink
-
The underlying sink where logs are processed and output.
final
Methods
-
dispose(
) → Future< void> -
Performs cleanup, such as closing file handles or network connections.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
output(
Uint8List document, LogEntry entry, LogLevel level, LogPipelineFactory factory) → Future< void> -
Outputs the
datato the destination.override -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited