SectionNode class final
A collapsible/expandable section.
- Inheritance
-
- Object
- LogNode
- LayoutNode
- SectionNode
Constructors
-
SectionNode({required List<
LogNode> children, required LogNode summary, int tags = LogTag.none}) - Creating a SectionNode.
Properties
-
children
↔ List<
LogNode> -
The child nodes contained within this layout structure.
getter/setter pairinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- summary ↔ LogNode
-
The summary/header that acts as a trigger for the section.
getter/setter pair
-
Semantic tags describing this node.
getter/setter pairinherited
- title ↔ StyledText?
-
Optional title or label for this structural block (e.g., box title).
getter/setter pairinherited
Methods
-
copyWith(
{List< LogNode> ? children, StyledText? title, int? tags, LogNode? summary}) → SectionNode -
Creates a copy of this node with optional changes.
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
releaseRecursive(
LogPipelineFactory factory) → void -
Releases this node and any children back to
factory.override -
reset(
) → void -
Resets this node's fields to their defaults for pool reuse.
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited