StandardEngine class
A LogEngine that utilizes Dart language's standard heap allocation.
This implementation relies on the language's native garbage collector for object lifecycle management. It is designed for optimal readability and maintainability, making it the suitable default for most applications where main-thread GC pressure is not a primary constraint.
- Implemented types
Constructors
- StandardEngine()
-
A LogEngine that uses standard heap allocation.
const
Properties
- factory → LogPipelineFactory
-
The factory/allocator used by this engine for pipeline resources.
no setteroverride
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
execute(
LogEntry entry, LogFormatter formatter, List< LogDecorator> decorators, LogSink sink) → Future<void> -
Executes the pipeline for a single LogEntry.
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited