StructuralDecorator class abstract
A decorator that modifies the layout or structure of log output. Examples: BoxDecorator, adding dividers, or indentation.
- Inheritance
-
- Object
- LogDecorator
- StructuralDecorator
- Implementers
Constructors
- StructuralDecorator()
-
Constant constructor for subclasses.
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
decorate(
LogDocument document, LogEntry entry, LogPipelineFactory factory) → void -
Decorates the
documentin-place based on theentry, usingfactoryfor new nodes.inherited -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
paddingWidth(
LogEntry entry) → int -
Returns the width in terminal cells this decorator adds to each line.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited