CapturedLog class
Represents a logged entry captured in tests.
Constructors
-
CapturedLog({required LogLevel level, required String message, required String loggerName, required String origin, Object? error, StackTrace? stackTrace, Map<
String, dynamic> ? context}) - Creates a new CapturedLog instance.
Properties
-
context
→ Map<
String, dynamic> ? -
The optional associated context map.
final
- error → Object?
-
The optional associated error.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- level → LogLevel
-
The level of this log event.
final
- loggerName → String
-
The name of the logger.
final
- message → String
-
The formatted message string.
final
- origin → String
-
The file/class origin header.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- stackTrace → StackTrace?
-
The optional associated stack trace.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited